==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebToggleViewCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescription } from "./WebToggleViewCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebToggleViewCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewCancelableEventArgsDescriptionMetadata.a == null) {
                WebToggleViewCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewCancelableEventArgsDescriptionMetadata.c(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebToggleViewCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebToggleViewCancelableEventArgsDetail");
        }
        static d(a) {
            WebToggleViewCancelableEventArgsDescriptionMetadata.b(a);
            a.aa("WebToggleViewCancelableEventArgs", () => new WebToggleViewCancelableEventArgsDescription());
            a.z("WebToggleViewCancelableEventArgs", WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebToggleViewCancelableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewCancelableEventArgsDescriptionMetadata, 'WebToggleViewCancelableEventArgsDescriptionMetadata');
    WebToggleViewCancelableEventArgsDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebToggleViewCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewCancelableEventArgsDetailDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDetailDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescription } from "./WebToggleViewCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebToggleViewCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewCancelableEventArgsDescriptionMetadata.a == null) {
                WebToggleViewCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewCancelableEventArgsDescriptionMetadata.c(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebToggleViewCancelableEventArgsDescriptionMetadata.a);
            WebToggleViewCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleViewCancelableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebToggleViewCancelableEventArgsDetail");
        }
        static d(a) {
            WebToggleViewCancelableEventArgsDescriptionMetadata.b(a);
            a.ac("WebToggleViewCancelableEventArgs", () => new WebToggleViewCancelableEventArgsDescription());
            a.ab("WebToggleViewCancelableEventArgs", WebToggleViewCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebToggleViewCancelableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleViewCancelableEventArgsDescriptionMetadata, 'WebToggleViewCancelableEventArgsDescriptionMetadata');
    WebToggleViewCancelableEventArgsDescriptionMetadata.a = null;
    return WebToggleViewCancelableEventArgsDescriptionMetadata;
})();
